==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/QQuickPaintedItem_shell.h <==
#ifndef QQUICKPAINTEDITEM_SHELL_H
#define QQUICKPAINTEDITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickpainteditem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtransform.h>
#include <QtJambi/JavaAPI>
#include <QtQml/qjsvalue.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtextureprovider.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QQuickPaintedItem_shell : public QQuickPaintedItem, public QtJambiShellInterface
{
public:
    QQuickPaintedItem_shell(QQuickItem* parent0 = nullptr);
    ~QQuickPaintedItem_shell() override;

    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool childMouseEventFilter(QQuickItem* arg__1, QEvent* arg__2) override;
    void classBegin() override;
    QRectF clipRect() const override;
    void componentComplete() override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* arg__1) override;
    void dragLeaveEvent(QDragLeaveEvent* arg__1) override;
    void dragMoveEvent(QDragMoveEvent* arg__1) override;
    void dropEvent(QDropEvent* arg__1) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    void geometryChanged(const QRectF& newGeometry0, const QRectF& oldGeometry1) override;
    void hoverEnterEvent(QHoverEvent* event0) override;
    void hoverLeaveEvent(QHoverEvent* event0) override;
    void hoverMoveEvent(QHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isTextureProvider() const override;
    void itemChange(QQuickItem::ItemChange arg__1, const QQuickItem::ItemChangeData& arg__2) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void mouseUngrabEvent() override;
    void paint(QPainter* painter0) override;
    void releaseResources() override;
    QSGTextureProvider* textureProvider() const override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void touchUngrabEvent() override;
    QSGNode* updatePaintNode(QSGNode* arg__1, QQuickItem::UpdatePaintNodeData* arg__2) override;
    void updatePolish() override;
    void wheelEvent(QWheelEvent* event0) override;
    void windowDeactivateEvent() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickPaintedItem_access : public QQuickPaintedItem
{
    jboolean __qt_isTextureProvider(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_itemChange_QQuickItem_ItemChange_cref_QQuickItem_ItemChangeData(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1, jobject arg__2);
    void __qt_paint_QPainter_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0);
    void __qt_releaseResources(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_textureProvider(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_updatePaintNode_QSGNode_ptr_QQuickItem_UpdatePaintNodeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
};

#endif // QQUICKPAINTEDITEM_SHELL_H

==> qtjambi-quick-debuginfo-macos-5.15.20.jar: sources/QtJambiQuick/QQuickPaintedItem_shell.h <==
#ifndef QQUICKPAINTEDITEM_SHELL_H
#define QQUICKPAINTEDITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickpainteditem.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtransform.h>
#include <QtJambi/JavaAPI>
#include <QtQml/qjsvalue.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtextureprovider.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QQuickPaintedItem_shell : public QQuickPaintedItem, public QtJambiShellInterface
{
public:
    QQuickPaintedItem_shell(QQuickItem* parent0 = nullptr);
    ~QQuickPaintedItem_shell() override;

    QRectF boundingRect() const override;
    void childEvent(QChildEvent* event0) override;
    bool childMouseEventFilter(QQuickItem* arg__1, QEvent* arg__2) override;
    void classBegin() override;
    QRectF clipRect() const override;
    void componentComplete() override;
    void connectNotify(const QMetaMethod& signal0) override;
    bool contains(const QPointF& point0) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void dragEnterEvent(QDragEnterEvent* arg__1) override;
    void dragLeaveEvent(QDragLeaveEvent* arg__1) override;
    void dragMoveEvent(QDragMoveEvent* arg__1) override;
    void dropEvent(QDropEvent* arg__1) override;
    bool event(QEvent* arg__1) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    void geometryChanged(const QRectF& newGeometry0, const QRectF& oldGeometry1) override;
    void hoverEnterEvent(QHoverEvent* event0) override;
    void hoverLeaveEvent(QHoverEvent* event0) override;
    void hoverMoveEvent(QHoverEvent* event0) override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery query0) const override;
    bool isTextureProvider() const override;
    void itemChange(QQuickItem::ItemChange arg__1, const QQuickItem::ItemChangeData& arg__2) override;
    void keyPressEvent(QKeyEvent* event0) override;
    void keyReleaseEvent(QKeyEvent* event0) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0) override;
    void mousePressEvent(QMouseEvent* event0) override;
    void mouseReleaseEvent(QMouseEvent* event0) override;
    void mouseUngrabEvent() override;
    void paint(QPainter* painter0) override;
    void releaseResources() override;
    QSGTextureProvider* textureProvider() const override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void touchUngrabEvent() override;
    QSGNode* updatePaintNode(QSGNode* arg__1, QQuickItem::UpdatePaintNodeData* arg__2) override;
    void updatePolish() override;
    void wheelEvent(QWheelEvent* event0) override;
    void windowDeactivateEvent() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickPaintedItem_access : public QQuickPaintedItem
{
    jboolean __qt_isTextureProvider_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_itemChange_QQuickItem_ItemChange_cref_QQuickItem_ItemChangeData(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1, jobject arg__2);
    void __qt_paint_QPainter_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0);
    void __qt_releaseResources(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_textureProvider_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_updatePaintNode_QSGNode_ptr_QQuickItem_UpdatePaintNodeData_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1, QtJambiNativeID arg__2);
};

#endif // QQUICKPAINTEDITEM_SHELL_H
